{{Header110208a.spin 
  Modified G101011c.spin

  This file contains the costants used in many objects.
  The objects on used with the following boards.
  
  Boards
  A Main data collection board.  Records information to uSD card and transmits the
    information to board H.  
  B This gathers data from serial lines and transfer to board A.
  C VGA display board.  Also has an Emic
  D Controls LED Array and seven segment display.  Receives data from C (or should it be A?).
  E Wireless barcode reader.
  F Input devices; encoder knobs and buttons, keyboard, Nordic tranceiver.  Slave to board G.
  G This board.  Propeller Touchscreen Platform used to control, monitor (and record?) lab and household equipment.
  H Basestation.  
  *I Drying oven controller.
  *J Robot arm controller.
  *X Roboni I controller?
  *Y Kitchen over controller.
  Z Sprinkler controller.  (Maybe use other naming system for houshold boards.)
  


  '' Communication protocol.  Board to board.
  '' Hard wired boards:
  '' _StartOfHeader _StartOfText (destination board letter*1) (origination board letter)(_Enquire, _Acknowledgment or _Command) 
  '' [type of E, A or C] [parameters] _CarriageReturn
  ''
  '' Wireless boards:
  '' _StartOfHeader _StartOfText (board letter*2)(origination board letter) (transmission count*3) (_Enquire, _Acknowledgment or _Command) 
  '' [type of E, A or C] [parameters] _CarriageReturn
  ''
  '' *1 Is this needed?  All wired com will go directly to one board.  Receiving board should be told the destination so it
  ''    knows if it needs to act on the communcation or just pass it on.  Probably leave in.
  '' *2 The transceiver may need to be configured to transmit to different boards.
  '' *3 Transmission count (use txCount) will increment by one each transmission so receiving board will know if data is repeated.
  ''    An ackowledgment will include the original count as a parameter.  (Use RxCountOld and RxCountNew)

  Boards A and B communications
  Since board B will only be communicating with board A the protocol will be different.
  Board B will add a small header to indicate the type of information being transmitted.
  There will be an uppercase letter to indicate the type of information followed by an colon.
  The letters supported so far are:
  A: for analytical balance data.
    After the header the weight will be transmitted ending with the character "g".
    The numbers 0-9, a decimal point "." and a leading negative may be part of the
    transmission.  The balance transmits a "+" to indicate positive weight; this character
    is ignored by board B.  There are also several space characters transmitted after the
    plus sign.  These are also ignored.
  L: for large balance data.
    After the header the weight will be transmitted ending with the character "g".
    The numbers 0-9, a decimal point "." and a leading negative may be part of the
    transmission.  The large balance does not transmit a negative sign (I don't know why).
    The "g" character indicates the end of the weight information.  The balance transmits
    additional characters after the weight which is ignored by board B.
  S: for spectrometer data.  This may need a sub header to indicate the type of spectrometer data.
    The spectrometer data will be passed on to board A with the space characters removed and a
    comma added to separate the fields.  Wave length (ending with NM), decimal number with posible
    negative sign, single letter mode indicator.  Board A will need to monitor this information to
    make sure the correct wavelength is being used and to make sure the spectrometer is in the
    correct mode.  Board A may change the mode automatically by transmitting the appropiate command
    to the spectrometer.
  B: for barcode data.
    Board B should not need to modify the data it receives from the barcode reader.  Board A
    will use the intial characters of the barcode to determine the type of container.
  E: error message.
    Possible errors include: spectrometer in the wrong mode.
    Board B should make an error sound with its piezo speaker.  
  D: not any of above, other communication.  Probably just to pass on to be displayed.
    Should everything that is displayed also be recorded?  Not for now.
    Is everthing that is displayed also spoken by the eMic module?
  X: debug input on board B.
    Just pass it along to boards C and H and record it to SC card.
  Each data packet will end with a carriage return(13).

  Wireless transmission will be acknowledged with the character R followed by the setCount variable
  sent back to originating board.

  The object pcFullDuplexSerial4FC512FlagsPlus110304a sets the acknowledge flag from within the PASM
  section of the driver (only on port 0).

  
}}  
  'Control ASCII characters used in object.              
  {_StartOfHeader = 1
  _StartOfText = 2
  _SendToWireLess = 3          ' Used by board F to acknowledge to G a wireless Tx was send and has been received by distination
                                ' board.
  _Command = 4                 ' Followed by board destination. Use to indicate action required by other Prop such as lighting a LED
  _Enquire = 5                  ' Follow by board destination.  (A to F or higher in future)
  _Acknowledgment = 6
  _CarriageReturn = 13          ' I doubt I'll use the constant's name.  I'll just type 13.
  '' _Enquire types
  '' Also use in CheckStylusDown method as modes
  _Button = 14
  _ButtonAndKnob = 15
  _ButtonKnobAndKey = 16
  _ButtonKnobKeyAndNunchuck = 17
  '' _Command types
  _LedSingle = 18
  _LedGroup = 19
  _StopTxNunchuckToRoboni0 = 20
  _StartTxNunchuckToRoboni0 = 21  }

  #0, _Null, _StartOfHeader, _StartOfText, _SendToWireLess, _Command, _Enquire, _Acknowledgment, { 0-6

    _Enquire types, Also use in CheckStylusDown method as modes
    } _Button, _ButtonAndKnob, _ButtonKnobAndKey, _ButtonKnobKeyAndNunchuck, _LedSingle, _LedGroup, { 7-12
    } _CarriageReturn, _StopTxNunchuckToRoboni0, _StartTxNunchuckToRoboni0   {13-15} 
  
  _WirelessAck = "R"

  ' Other codes used.  These will follow one or more control characters.
  '_RtcInUseFlagF = 22
  '_RtcInUseFlagG = 23

  
  
  ' Button and Knob enumeration
  ' button or knob zero, one, two or all (enquire about all buttons and knobs)
  #0, _Input0, _Input1, _Input2, _InputAll  
 ' Pin Definitions

  _ClockAddress = %1101000

  _DebugBaudA = 57600  
  _DebugBaudB = 57600  
  _DebugBaudC = 57600   
  _DebugBaudD = 57600
  _DebugBaudE = 57600  
  _DebugBaudF = 57600  
  _DebugBaudG = 57600    
  _DebugBaudH = 57600    
  _DebugBaudZ = 57600    
  _DebugBaudTestBoard1 = 57600    
      
  _ABBoardsBaud = 57600
  _BCBoardsBaud = 57600
  _XBeeBaud = 9600
  _EmicBaud = 2400
  _FieldSizeComrade = 12
 
  _LargeBufferSize = 512 '128 '32
  _LargestStructureSize = 32 '_LargeBufferSize
  
  _DefaultMainDutyCycle = 2 '30
  _DefaultPerimeterDutyCycle = 10 '50
  _DefaultClockDutyCycle = 50
  _DefaultClockMode = 2         ' _ClockAmPm
  _DefaultLedFrequency = 1000
  _DefaultRoboniMotorFrequency = 100

  _PayloadSize = 24
  _BarcodeQueMax = 10
  _LargeBufferSizeTimesQue = _LargeBufferSize * _BarcodeQueMax
  _StackSize = 100 '64
  _TxAttempts = 32
  _DisplayTimePeriod = 300      ' five minutes

  _XBeeTimeout = 280_000_000 ' 80_000_000 per second  3.5 seconds
  _XBeeTimeoutRx = 60_000_000 '40_000_000 '  1/2 second may need adjusting
  
  _XBeeRxtime = 250             ' quarter of a second, decrease when there are few debug statements.
  _XBeeSettingsAttempts = 4
  _XBeeSerialSize = 8
  _XBeeNameFieldSize = 12
  _XBeeCount = 6
  
  
  '' LED enumeration
  #0, _MainLeds, _PerimeterLeds, _ClockLeds
  
  '' Mode enumeration
  #0, _CenteredMode, _LeftAligned, _RightAligned

  '' Spectrometer mode enumeration
  #0, _AbsorbanceSpec, _TransmittanceSpec, _ConcentrationSpec, _FactorSpec, _UnknownSpec
  
  '' Clock mode enumeration
  #0, _ClockDefault, _ClockMilitary, _ClockAmPm

  '' WaitStylusDown mode enumeration
  '#0, _ButtonsOnly, _ButtonsAndKnobs, _ButtonsAndKeys, _ButtonsKnobsAndKeys

  '' Oven enumeration
  #0, _Humic, _LabWare, _Kitchen

  ' transceiver enumeration
  #1, _NordicA, _NordicBaseStation, _NordicInputDevice, _NordicD, _Roboni0

  ' XBee board letters enumeration
  #0, _XBeeA, _XBeeE, _XBeeH

  ' XBee names enumeration
  #0, _Coordinator, _Barcode, _Backup, _Sam, _Fred, _Broadcast

  _DefaultTargetXBeeBoardA = _Backup
  _DefaultTargetXBeeBoardE = _Coordinator
  _DefaultTargetXBeeBoardH = _Coordinator
  
  _DefaultAttachedXBeeBoardA = _Coordinator
  _DefaultAttachedXBeeBoardE = _Barcode
  _DefaultAttachedXBeeBoardH = _Backup
  
  ' XBee settings type enumeration
  #0, _AttachedSerial, _TargetSerial

  ' Message type enumeration used in setCount
  #0, _OutgoingCount, _IncomingCount

  ' Wireless Rx Types
  #0, _UnknownRx, _NormalRx, _AcknowledgementRx

           
  ' Emic priority emuneration
  #0, _Reserved0, _Reserved1, _Reserved3, _UrgentImportant, _Important, _Reserved6, _Reserved7, _Reserved8, {
    } _Reserved9, _Reserved10
    
PUB ThrowAwayMethod